@@ -3,10 +3,10 @@
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on November 21, 2023
+##   Last updated on March 1, 2024
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
-##   SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>
+##   SPDX-FileCopyrightText: 1998-2024 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,8 +27,13 @@
 
 set -o pipefail
 
+function cleanup {
+	pkill -9 -P $$
+}
+trap cleanup EXIT
+
 print_version() {
-	echo "$(basename "$0") 17.0"
+	echo "$(basename "$0") 19.0"
 	exit 0
 }
 
@@ -49,9 +54,9 @@ if [[ "$(command -v timeout)" == *"System32"* ]] || [[ "$(command -v timeout)" =
 	timeout_command=""
 # second, look for GNU coreutils package timeout command
 elif [ -x "$(command -v timeout)" ] && [[ "$(timeout --version)" == *"GNU coreutils"* ]] ; then
-	timeout_command="timeout -s 9 -k 1.0s"
+	timeout_command="timeout --foreground -s 9 -k 1.0s"
 elif [ -x "$(command -v gtimeout)" ] && [[ "$(gtimeout --version)" == *"GNU coreutils"* ]] ; then
-	timeout_command="gtimeout -s 9 -k 1.0s"
+	timeout_command="gtimeout --foreground -s 9 -k 1.0s"
 else
 	timeout_command=""
 fi
